@@ -1,7 +1,7 @@
 import json
 
 from logging import Formatter
-from ..utils.package import defaults
+from ..utils.package import JSON_DEFAULTS
 
 
 class JSONFormatter(Formatter):
@@ -11,7 +11,7 @@ class JSONFormatter(Formatter):
     def __format(self, record):
         message = record.message
         level = record.levelname
-        obj = {"level": level.lower(), "message": str(message)} | defaults()
+        obj = {"level": level.lower(), "message": str(message)} | JSON_DEFAULTS
 
         if hasattr(record, "stack") and record.stack is not None:
             obj["stack"] = record.stack
